@@ -17,7 +17,7 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 // Copyright Author Dany De Bontridder ddebontridder@yahoo.fr
-/* $Revision: 1.50 $ */
+/* $Revision: 1.52 $ */
 include_once("preference.php");
 include_once("fiche_inc.php");
 include_once("user_common.php");
@@ -317,6 +317,7 @@ function FormVente($p_cn,$p_jrn,$p_user,$p_array=null,$view_only=true,$p_article
     $W1->value=$march;
     $W1->extra='cred';  // credits
     $W1->extra2=$p_jrn;
+    $W1->readonly=$view_only;
     $r.="<TR>".$W1->IOValue()."</TD>";
 
     // card's name
@@ -844,6 +845,7 @@ function FormAch($p_cn,$p_jrn,$p_user,$p_submit,$p_array=null,$view_only=true,$p
   $W1->value=$e_client;
   $W1->extra='cred';
   $W1->extra2=$p_jrn;
+  $W1->readonly=$p_viewonly;
   $r.="<TR>".$W1->IOValue();
   $r.=       InputType(""       ,"span"   ,"e_client_label",$e_client_label,false).'</TR>';
   $r.="</TABLE>";
@@ -1295,6 +1297,7 @@ function FormFin($p_cn,$p_jrn,$p_user,$p_submit,$p_array=null,$view_only=true,$p
     $W1->value=$tiers;
     $W1->extra='cred';  // credits
     $W1->extra2=$p_jrn;
+    $W1->readonly=$p_viewonly;
     $r.="<TR>".$W1->IOValue()."</TD>";
 
     $r.=InputType("","span", "e_other$i"."_label", $tiers_label,$view_only);
@@ -1546,6 +1549,7 @@ function FormODS($p_cn,$p_jrn,$p_user,$p_submit,$p_array=null,$view_only=true,$p
     else
       $filter=null;
     $W = new widget('js_search_poste');
+    $W->readonly=$view_only;
     $W->label="";
     $W->extra=$p_jrn;
     $W->extra2=$filter;
