@@ -16,7 +16,7 @@
  *   along with PhpCompta; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-/* $Revision: 1.41 $ */
+/* $Revision: 1.42 $ */
 // Copyright Author Dany De Bontridder ddebontridder@yahoo.fr
 
 include_once("postgres.php");
@@ -188,7 +188,7 @@ function InsertJrnx($p_cn,$p_type,$p_user,$p_jrn,$p_poste,$p_date,$p_amount,$p_g
 
 function InsertJrn($p_cn,$p_date,$p_echeance,$p_jrn,$p_comment,$p_amount,$p_grpt,$p_periode)
 {
-	echo_debug ("InsertJrn param 
+	echo_debug (__FILE__,__LINE__,"InsertJrn param 
 	    p_date $p_date p_poste $p_comment p_amount $p_amount p_grpt = $p_grpt p_periode = $p_periode p_echeance = $p_echeance
 comment = $p_comment");
 	$p_comment=FormatString($p_comment);
